.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "0.02",
.\"     date            = "16 September 1996",
.\"     time            = "18:36:12 MDT",
.\"     filename        = "bibjoin.man",
.\"     address         = "Center for Scientific Computing
.\"                        Department of Mathematics
.\"                        University of Utah
.\"                        Salt Lake City, UT 84112
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 581 4148",
.\"     checksum        = "06292 285 1296 9278",
.\"     email           = "beebe@math.utah.edu (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "bibliography, sorting, BibTeX",
.\"     supported       = "yes",
.\"     docstring       = "This file contains the UNIX manual pages
.\"                        for the bibjoin utility, a program for
.\"                        ordering key fields in BibTeX bibliography
.\"                        files.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.if t .ds Bi B\s-2IB\s+2T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Bi BibTeX
.if t .ds Te T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Te TeX
.TH BIBJOIN 1 "16 September 1996" "Version 0.02"
.\"======================================================================
.SH NAME
bibjoin \- join duplicate or similar entries in a BibTeX bibliography file
.\"======================================================================
.SH SYNOPSIS
.B bibjoin
.RB [ \-check-missing ]
.RB [ \-version ]
< infile > outfile
.nf
or
.fi
.B bibjoin
.RB [ \-check-missing ]
.RB [ \-version ]
BibTeXfile(s)
> outfile
.\"======================================================================
.SH DESCRIPTION
.B bibjoin
filters one or more \*(Bi\& bibliographies, or
bibliography fragments, from the specified files,
or from its standard input if no filenames are
provided, printing on standard output a
bibliography in which adjacent duplicate, or
similar, entries have been joined into one entry.
Such action may be necessary when bibliography
entries are collected from many sources.
.PP
.B bibjoin
should be applied to a bibliography file only
after entries have been suitably ordered so that
candidates for joining appear consecutively.  This
can be done mostly automatically if standardized
citation labels are first generated, then the
bibliography is sorted by citation labels, such as
by
.BR bibsort (1).
.PP
Only a human reader can reliably decide when two
bibliography entries are truly the same.
.B bibjoin
can help automate much of this work, but manual
editing will almost certainly still be necessary.
If two entries are joined, these conditions must
be satisfied:
.RS
.TP \w'\(bu'u+1n
\(bu
identical citation labels;
.TP
\(bu
identical year;
.TP
\(bu
if a journal article entry, identical volume, and
if both have page numbers, identical initial page
numbers.
.RE
When two `equal' value strings are found for the
same key, one of them is deleted.  Otherwise, both
key/value pairs are output.  Manual editing will
then be required to choose between them.
.PP
Special handling is supplied for `pages' entries.
If entries are found with identical initial page
numbers, but one of them has question marks in
place of the final page number, or has no final
page number at all, such as "123--127", "123--??",
and "123", then the ones with the question marks
or no final page numbers will be dropped.  This
facilitates merging in data from library databases
that do not record final page numbers.
.PP
Special handling is also supplied for `author' and
`editor' fields.  When a personal name appears in
two forms, one with initials, and one without,
such as `P. D. Q. Bach' and `Philippe D. Q. Bach',
the names are considered to match, and the longer
form is retained.  In addition, to deal with the
UnCover database practice of omitting authors 4,
5, ..., N-1, two author/editor personal name lists
are considered to match if one has 3 names and the
other more than 3, and the first, second, and last
match as above; the longer form is retained.
.PP
Value strings are considered equal if they match
after all non-alphanumeric characters are removed,
and letter case is ignored.  This choice helps to
eliminate many match failures that arise from
minor variations in punctuation, spacing, and
capitalization.
.B bibjoin
has no way of determining which of the two strings
should be preserved, so it uniformly discards the
shorter one (which presumably has less
`information'): this choice will frequently be
.IR wrong !
.PP
Syntax errors in the input stream will cause
abrupt termination with a fatal error message and
a non-zero exit code.  The output will be
incomplete, so you should always examine the
output file before assuming that you can replace
the input file with the output file.
.PP
Key/value pairs in output entries are sorted
alphabetically by key name, so that duplicate keys
arising from the join operation appear
consecutively, simplifying the subsequent manual
editing task.
.PP
After completion of manual corrections,
it is recommended that the bibliography be
processed by
.BR biborder (1)
to standardize key/value order, and to check for
any remaining duplicate keys or citation labels.
.\"======================================================================
.SH OPTIONS
Command-line options may be abbreviated to a
unique leading prefix.
.PP
To avoid confusion with options, if a filename
begins with a hyphen, it must be disguised by a
leading absolute or relative directory path, e.g.
.I /tmp/-foo.bib
or
.IR ./-foo.bib .
.\"-----------------------------------------------
.TP \w'\-check-missing'u+3n
.B \-check-missing
If this option is specified, missing expected key
fields will be supplied, with the key field name
prefixed with OPT, and the value string set to a
pair of question marks, e.g.
.nf
  OPTvolume =    "??",
.fi
The
.I OPT
prefix ensures that the key is ignored by \*(Bi\&,
so that the question marks will not appear in an
output
.I .bbl
file.  The GNU Emacs
.I bibtex-mode
editing support has functions for removing the OPT
prefixes, and so does
.BR bibclean (1).
.IP
The doubled question marks are distinguished from
single ones that might legitimately appear in
value strings, and also serve as a convenient
regular-expression pattern for
.BR bibextract (1),
allowing easy preparation of a printed listing of
just those entries that have incomplete
bibliographic data:
.nf
.BI "     bibextract" " '' '[?][?]' BibTeXfiles " "|  lpr"
.fi
.\"-----------------------------------------------
.TP
.B \-version
Display the
.B bibjoin
version number and date on
.IR stdout ,
and then exit immediately.
.\"======================================================================
.SH "WARNING AND ERROR MESSAGES"
.B bibjoin
will issue warning messages in the following
cases:
.TP \w'\(bu'u+1n
\(bu
With
.BR \-check-missing ,
for unrecognized \*(Bi\& entry types.  The entry
will be output without checking for missing key
names.
.TP
\(bu
For duplicate key names.  Such key/value pairs are
sorted together by name, preserving their original
order.
.PP
.B bibjoin
will issue an error message and terminate with
exit code 1, and incomplete output, in the
following cases:
.TP \w'\(bu'u+1n
\(bu
For an unrecognized command-line argument (only
the first letter of each option is currently
examined).
.TP
\(bu
End-of-file is reached while collecting an entry.
.TP
\(bu
A line beginning with `@' is encountered while
collecting an entry, before balanced braces have
been found.
.\"======================================================================
.SH CAVEATS
\*(Bi\& has loose syntactical requirements that
the current simple implementation of
.B bibjoin
does not support.  In particular, outer
parentheses may
.I not
be used in place of braces following ``@keyword''
patterns.  If you have such a file, you can use
.BR bibclean (1)
to prettyprint it into a form that
.B bibjoin
can handle successfully.
.\"======================================================================
.SH "SEE ALSO"
.BR bibcheck (1),
.BR bibclean (1),
.BR bibdup (1),
.BR bibextract (1),
.BR biblabel (1),
.BR biblex (1),
.BR biborder (1),
.BR bibparse (1),
.BR bibsort (1),
.BR bibtex (1),
.BR bibunlex (1),
.BR citesub (1),
.BR emacs (1).
.\"======================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe, Ph.D.
Center for Scientific Computing
Department of Mathematics
University of Utah
Salt Lake City, UT 84112
Tel: +1 801 581 5254
FAX: +1 801 581 4148
Email: <beebe@math.utah.edu>
WWW URL: http://www.math.utah.edu/~beebe
.fi
.\"==============================[The End]==============================
